## What's Changed

- fix: 只跳过 AstrBot 预设的位于开头的 System Message，防止一些非预期行为。
- feat: 优化 ChatUI 默认的 System Message
- feat: 新增 tool 调用时 `on_using_llm_tool`、tool 调用后 `on_llm_tool_respond` 的事件钩子。
- feat: 优化 ChatUI 对 Tavily 网页搜索工具的渲染，支持内联搜索引用、引用网页。


hotfix of 4.12.2

- fix: tool call error in some cases

